(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    147625,       3701]
NotebookOptionsPosition[    144017,       3614]
NotebookOutlinePosition[    144374,       3630]
CellTagsIndexPosition[    144331,       3627]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
(* Package implementing the LZZ proof rule (InvS[]) for checking the \
invariance of semialgebraic sets (). 

Copyright (c) 2015,2016,2017, 
Andrew Sogokon (andrew.sogokon -\[ForAll]\[UpTee]- vanderbilt.edu)
Khalil Ghorbal (khalil.ghorbal -\[ForAll]\[UpTee]- inria.fr)
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the <organization> nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\" \
AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*)\
\>", "Text",
 CellChangeTimes->{
  3.714385705074066*^9},ExpressionUUID->"79ddb1b2-2733-49c0-8b54-\
0af0d15b84d3"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Semi", "-", 
   RowBox[{
   "algebraic", " ", "invariant", " ", "checking", " ", "benchmarks"}]}], " ",
   "*)"}]], "Input",
 CellChangeTimes->{{3.638965892395671*^9, 3.6389659227858057`*^9}, 
   3.639138526074004*^9},ExpressionUUID->"bedb01e8-10f7-4a78-a0d8-\
0929b1c70bc5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InvariantsDI", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "2"], "\[GreaterEqual]", "0"}], "&&", 
        RowBox[{
         SubscriptBox["x", "1"], "\[GreaterEqual]", "0"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["x", "2", "2"], ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"Simple", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], 
          SubscriptBox["x", "2"], 
          SubscriptBox["x", "3"]}], " ", "\[Equal]", 
         RowBox[{"1", "/", "16"}]}], " ", "&&", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], "+", 
          SubscriptBox["x", "2"], "+", 
          SubscriptBox["x", "3"]}], "\[Equal]", 
         RowBox[{"33", "/", "16"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "3"], "-", 
            SubscriptBox["x", "2"]}], ")"}]}], ",", 
         RowBox[{
          SubscriptBox["x", "2"], 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "-", 
            SubscriptBox["x", "3"]}], ")"}]}], ",", " ", 
         RowBox[{
          SubscriptBox["x", "3"], 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "2"], "-", 
            SubscriptBox["x", "1"]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{"Algebraically", " ", "integrable", " ", "system"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], "\[GreaterEqual]", " ", "2"}], " ", "||", 
        " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], "+", 
          SubscriptBox["x", "2"]}], "\[GreaterEqual]", "0"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], " ", "+", "3"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            SubscriptBox["x", "2"]}], ")"}], "^", "4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", " ", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], "\[GreaterEqual]", " ", "2"}], " ", "||", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "+", 
           SubscriptBox["x", "2"]}], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
         RowBox[{
          SubscriptBox["x", "3"], " ", ">=", 
          RowBox[{"-", "1"}]}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], " ", "+", "3"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            SubscriptBox["x", "2"]}], ")"}], "^", "4"}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "3"], "+", 
             SubscriptBox["x", "1"], "+", 
             SubscriptBox["x", "2"]}], ")"}], "^", "2"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "2"], " ", "-", 
             RowBox[{
              SubscriptBox["x", "3"], "^", "3"}]}], ")"}], "^", "4"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", " ", 
         SubscriptBox["x", "3"]}], "}"}], ",", " ", "True"}], "}"}], ",", " ",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], " ", "+", 
          SubscriptBox["x", "3"]}], "\[GreaterEqual]", " ", "0"}], " ", "||", 
        " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "+", 
           SubscriptBox["x", "2"]}], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
         RowBox[{
          SubscriptBox["x", "3"], " ", ">=", "0"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["x", "1"], "^", "4"}], 
           RowBox[{
            SubscriptBox["x", "2"], "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{
            SubscriptBox["x", "1"], "^", "2"}], 
           RowBox[{
            SubscriptBox["x", "2"], "^", "4"}]}], "-", 
          RowBox[{"3", 
           RowBox[{
            SubscriptBox["x", "1"], "^", "2"}], 
           RowBox[{
            SubscriptBox["x", "2"], "^", "2"}]}], "+", "1"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            SubscriptBox["x", "2"], "+", 
            SubscriptBox["x", "3"]}], ")"}], "^", "2"}], ",", "  ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], " ", "-", 
            SubscriptBox["x", "3"]}], ")"}], "^", "2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", " ", 
         SubscriptBox["x", "3"]}], "}"}], ",", " ", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], " ", "+", 
          SubscriptBox["x", "2"]}], "\[GreaterEqual]", " ", "0"}], " ", "||", 
        
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "2"], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "3"], " ", "<=", "0"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "4"}], 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            SubscriptBox["x", "2"], "+", 
            SubscriptBox["x", "3"]}], ")"}], "^", "2"}], ",", "  ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["x", "3"], "^", "4"}], 
             RowBox[{
              SubscriptBox["x", "2"], "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "2"], "^", "4"}]}], "-", 
            RowBox[{"3", 
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "2"], "^", "2"}]}], "+", "1"}], ")"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", " ", 
         SubscriptBox["x", "3"]}], "}"}], ",", " ", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "2"], "\[GreaterEqual]", " ", "0"}], " ", "&&", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "<=", "0"}], " ", "||", " ", 
          RowBox[{
           SubscriptBox["x", "3"], " ", "\[GreaterEqual]", "0"}]}], ")"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "3"], "^", "6"}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "^", "4"}], 
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "2"], "^", "4"}]}], "+", 
            RowBox[{"3", 
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "2"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}]}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            SubscriptBox["x", "3"]}], ")"}], "^", "2"}], ",", "  ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["x", "3"], "^", "4"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "3"], "^", "2"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "4"}]}], "-", 
           RowBox[{"3", 
            RowBox[{
             SubscriptBox["x", "3"], "^", "2"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "2"}]}], "+", "1"}], ")"}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", " ", 
         SubscriptBox["x", "3"]}], "}"}], ",", " ", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], "+", 
          SubscriptBox["x", "2"], "+", 
          SubscriptBox["x", "3"]}], "\[GreaterEqual]", "0"}], " ", "||", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "2"], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "3"], "\[GreaterEqual]", "0"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "4"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "3"], "-", 
             SubscriptBox["x", "2"]}], ")"}], "^", "2"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "2"], "^", "6"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "-", 
             SubscriptBox["x", "3"]}], ")"}], "^", "2"}]}], ",", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "3"], "^", "8"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "2"], "-", 
             SubscriptBox["x", "1"]}], ")"}], "^", "2"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["x", "2"], "+", 
          SubscriptBox["x", "3"]}], "\[GreaterEqual]", "0"}], " ", "||", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "2"], "\[GreaterEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "3"], "\[GreaterEqual]", "0"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "3"], "-", 
             SubscriptBox["x", "2"]}], ")"}], "^", "4"}]}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["x", "3"], "^", "4"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "2"}]}], "+", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "3"], "^", "2"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "4"}]}], "-", 
           RowBox[{"3", 
            RowBox[{
             SubscriptBox["x", "3"], "^", "2"}], 
            RowBox[{
             SubscriptBox["x", "2"], "^", "2"}]}], "+", "1"}], ")"}], ",", 
         " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "3"], "^", "2"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "2"], "-", 
             SubscriptBox["x", "1"]}], ")"}], "^", "4"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "1"], "\[LessEqual]", "0"}], " ", "||", " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", 
           RowBox[{"2", " "}]], "\[LessEqual]", "0"}], " ", "&&", " ", 
         RowBox[{
          SubscriptBox["x", "3"], "\[GreaterEqual]", "0"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SubscriptBox["x", "3"], "^", "4"}], 
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "1"], "^", "4"}]}], "-", 
            RowBox[{"3", 
             RowBox[{
              SubscriptBox["x", "3"], "^", "2"}], 
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}]}], "+", "3"}], ")"}]}], ",", 
         
         RowBox[{"-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "+", 
             SubscriptBox["x", "2"], "+", 
             SubscriptBox["x", "3"]}], ")"}], "^", "2"}]}], ",", "  ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"10", "-", 
             SubscriptBox["x", "1"], "-", 
             SubscriptBox["x", "3"]}], ")"}], "^", "2"}], " ", "+", " ", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "4"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", " ", 
         SubscriptBox["x", "3"]}], "}"}], ",", " ", "True"}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.638965927599609*^9, 3.638965957622061*^9}, {
   3.638966014862403*^9, 3.6389660178195887`*^9}, {3.638966102647655*^9, 
   3.638966141149775*^9}, {3.63896619190248*^9, 3.6389663681400633`*^9}, {
   3.6389667818828382`*^9, 3.638966845830174*^9}, {3.638966903885964*^9, 
   3.638966942510192*^9}, {3.63896698352884*^9, 3.638966985382801*^9}, {
   3.6389670460383377`*^9, 3.6389670483781843`*^9}, 3.638967128752769*^9, {
   3.638967341993819*^9, 3.63896753930751*^9}, {3.638967619665073*^9, 
   3.638967706120867*^9}, {3.638967747679121*^9, 3.638967859202127*^9}, {
   3.638967957708291*^9, 3.638968037165381*^9}, {3.63896815503474*^9, 
   3.638968191847275*^9}, {3.638968286530835*^9, 3.638968488031307*^9}, {
   3.638968534311063*^9, 3.638968791740047*^9}, {3.638968874694016*^9, 
   3.638969047437675*^9}},ExpressionUUID->"5bf8d57e-38a3-487c-8b2a-\
4f268542fc40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Check", " ", "differential", " ", "invariants"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SemiAlgInv`DiffInv", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "&"}], ",", " ", 
       "InvariantsDI"}], "]"}], " ", "//", 
     RowBox[{"Timing", "\[IndentingNewLine]", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"SemiAlgInv`InvS", "[", 
          RowBox[{"Apply", "[", 
           RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "&"}], ",", " ",
         "InvariantsDI"}], "]"}]}]}], " ", "//", 
    RowBox[{"Timing", "\[IndentingNewLine]", 
     RowBox[{"Length", "[", "InvariantsDI", "]"}]}]}], " ", "*)"}]}]], "Input",\

 CellChangeTimes->{{3.6389660382643023`*^9, 3.638966091842163*^9}, {
  3.638968502370792*^9, 3.638968508070105*^9}, {3.638969065891843*^9, 
  3.638969095832849*^9}, {3.6391403731867523`*^9, 
  3.63914037579909*^9}},ExpressionUUID->"e0b79eca-2b4b-4c54-b3d2-\
9ff32e43b880"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InvariantsNSSBC", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "-", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}], "-", "2"}], "\[LessEqual]", 
         "0"}], " ", "&&", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "+", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}], "-", "2"}], "\[LessEqual]", 
         "0"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "1"], "^", "3"}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "2"], "^", "2"}], 
             SubscriptBox["x", "1"]}], "-", 
            SubscriptBox["x", "1"], "-", 
            SubscriptBox["x", "2"]}], ")"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "2"], "^", "3"}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}], 
             SubscriptBox["x", "2"]}], " ", "-", " ", 
            SubscriptBox["x", "2"], "+", 
            SubscriptBox["x", "1"]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{"Simple", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "-", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}], "-", "2"}], "\[LessEqual]", 
         "0"}], " ", "&&", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "+", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}], "-", "2"}], "\[LessEqual]", 
         "0"}], " ", "&&", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "2"], "-", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "-", "2"}], 
         "\[LessEqual]", "0"}], " ", "&&", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "2"], "+", 
             RowBox[{"1", "/", "3"}]}], ")"}], "^", "2"}], "-", "2"}], 
         "\[LessEqual]", "0"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "1"], "^", "3"}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "2"], "^", "2"}], 
             SubscriptBox["x", "1"]}], "-", 
            SubscriptBox["x", "1"], "-", 
            SubscriptBox["x", "2"]}], ")"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["x", "2"], "^", "3"}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "^", "2"}], 
             SubscriptBox["x", "2"]}], " ", "-", " ", 
            SubscriptBox["x", "2"], "+", 
            SubscriptBox["x", "1"]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"Simple", " ", "example", " ", "2"}], " ", "*)"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["2", "5"]}], "+", 
          SubsuperscriptBox["x", "1", "2"], "+", 
          SubsuperscriptBox["x", "2", "2"]}], "\[LessEqual]", "0"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "5"]}], "-", 
            SubscriptBox["x", "1"], "+", 
            FractionBox[
             SubscriptBox["x", "2"], "5"]}], "\[LessEqual]", "0"}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "5"]}], "+", 
            SubscriptBox["x", "1"], "+", 
            FractionBox[
             SubscriptBox["x", "2"], "5"]}], "\[LessEqual]", "0"}], "&&", 
          RowBox[{
           SubscriptBox["x", "2"], "\[LessEqual]", "0"}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], "-", 
            SubscriptBox["x", "2"]}], "\[LessEqual]", "0"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["x", "1"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "2"]}], "+", 
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], 
     RowBox[{"(*", " ", "Keyhole", " ", "*)"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["2", "5"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["19", "2"]}], "+", 
              FractionBox[
               RowBox[{"161", " ", 
                SubscriptBox["x", "1"]}], "100"], "+", 
              SubsuperscriptBox["x", "1", "2"], "+", 
              FractionBox[
               RowBox[{"157", " ", 
                SubscriptBox["x", "2"]}], "50"]}], ")"}]}], "\[LessEqual]", 
           "0"}], " ", "||", 
          RowBox[{
           RowBox[{"7", " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox["5", "2"], "+", 
              SubscriptBox["x", "1"], "-", 
              FractionBox[
               RowBox[{"9", " ", 
                SubscriptBox["x", "2"]}], "50"]}], ")"}]}], "\[LessEqual]", 
           "0"}]}], " ", ")"}], "&&", " ", 
        RowBox[{
         SubscriptBox["x", "2"], "\[GreaterEqual]", 
         RowBox[{"-", "2"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", 
           SubscriptBox["x", "1"]}], "+", 
          RowBox[{"2", 
           SubscriptBox["x", "2"]}]}], " ", ",", 
         RowBox[{
          SubscriptBox["x", "1"], "+", 
          SubscriptBox["x", "2"], "+", 
          RowBox[{
           SubscriptBox["x", "1"], "^", "4"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], 
     RowBox[{"(*", " ", 
      RowBox[{
      "ODE", " ", "from", " ", "Wiggins", " ", "Exercise", " ", "18.7", ".3", 
       " ", 
       RowBox[{"(", "d", ")"}]}], " ", "*)"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["7", "20"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["841", "100"]}], "+", 
              FractionBox[
               RowBox[{"94", " ", 
                SubscriptBox["x", "1"]}], "25"], "+", 
              SubsuperscriptBox["x", "1", "2"], "-", 
              FractionBox[
               RowBox[{"59", " ", 
                SubscriptBox["x", "2"]}], "10"], "+", 
              FractionBox[
               RowBox[{"123", " ", 
                SubscriptBox["x", "1"], " ", 
                SubscriptBox["x", "2"]}], "100"]}], ")"}]}], "\[LessEqual]", 
           "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{
            FractionBox["27", "50"], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox["89", "2"], "-", 
              FractionBox[
               RowBox[{"442", " ", 
                SubscriptBox["x", "1"]}], "25"], "+", 
              SubsuperscriptBox["x", "1", "2"], "-", 
              RowBox[{"13", " ", 
               SubscriptBox["x", "2"]}]}], ")"}]}], "\[LessEqual]", "0"}]}], 
         ")"}], "||", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"23", " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox["468", "25"], "+", 
               FractionBox[
                RowBox[{"77", " ", 
                 SubscriptBox["x", "1"]}], "10"], "+", 
               SubsuperscriptBox["x", "1", "2"], "+", 
               FractionBox[
                RowBox[{"567", " ", 
                 SubscriptBox["x", "2"]}], "100"]}], ")"}]}], "1000"], 
           "\[LessEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "1"], "\[LessEqual]", "0"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "2"], ",", " ", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], "+", 
          RowBox[{
           RowBox[{
            SubscriptBox["x", "1"], "^", "3"}], "/", "6"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ODE", " ", "taken", " ", "from", " ", "Tiwari"}], " ", 
         "&"}], " ", "Khanna"}], ",", " ", 
       RowBox[{"HSCC", " ", "2004"}], ",", " ", 
       RowBox[{"Example", " ", "8"}], ",", " ", 
       RowBox[{"Pendulum", "."}]}], " ", "*)"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"6441", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox["42693", "200"], "-", 
                FractionBox[
                 RowBox[{"15951", " ", 
                  SubscriptBox["x", "1"]}], "1000"], "+", 
                SubsuperscriptBox["x", "1", "2"], "+", 
                FractionBox[
                 RowBox[{"3071", " ", 
                  SubscriptBox["x", "2"]}], "50"], "-", 
                FractionBox[
                 RowBox[{"1863", " ", 
                  SubscriptBox["x", "1"], " ", 
                  SubscriptBox["x", "2"]}], "500"]}], ")"}]}], "500000"]}], 
           "\[LessEqual]", "0"}], "  ", "&&", " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["x", "2"], "+", 
            RowBox[{
             RowBox[{"2", "/", "4"}], 
             SubscriptBox["x", "1"]}]}], "\[GreaterEqual]", 
           RowBox[{"-", "5"}]}]}], ")"}], " ", "||", "  ", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "2"], "+", 
          RowBox[{
           RowBox[{"2", "/", "4"}], 
           SubscriptBox["x", "1"]}]}], "\[GreaterEqual]", "0"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubsuperscriptBox["x", "2", "3"], ",", 
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["x", "1", "3"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubsuperscriptBox["x", "1", "2"], " ", 
           SubsuperscriptBox["x", "2", "2"]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"ODE", " ", "from", " ", 
        RowBox[{"D", ".", " ", "Schlomiuk"}]}], ",", " ", 
       RowBox[{
       "Algebraic", " ", "and", " ", "Geometric", " ", "Aspects", " ", "of", 
        " ", "the", " ", "Theory", " ", "of", " ", "Polynomial", " ", 
        "Vector", " ", "Fields"}]}], " ", "*)"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"326931", " ", 
           SubsuperscriptBox["x", "1", "3"]}], "+", 
          RowBox[{
           SubsuperscriptBox["x", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "267530"}], "+", 
             RowBox[{"520354", " ", 
              SubscriptBox["x", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["x", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"13108800", "+", 
             RowBox[{"474097", " ", 
              SubscriptBox["x", "2"]}], "-", 
             RowBox[{"521128", " ", 
              SubsuperscriptBox["x", "2", "2"]}]}], ")"}]}], "+", 
          RowBox[{"10", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9817800"}], "-", 
             RowBox[{"925909", " ", 
              SubscriptBox["x", "2"]}], "+", 
             RowBox[{"482914", " ", 
              SubsuperscriptBox["x", "2", "2"]}], "+", 
             RowBox[{"10000", " ", 
              SubsuperscriptBox["x", "2", "3"]}]}], ")"}]}]}], 
         "\[GreaterEqual]", "0"}], "||", "   ", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], "-", 
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           SubscriptBox["x", "2"]}], "-", "4"}], "\[GreaterEqual]", "0"}], 
        " ", "||", " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "1"], "-", 
          RowBox[{"5", 
           SubscriptBox["x", "2"]}], "-", "50"}], ">=", "0"}], "  ", "||", 
        " ", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["x", "1"], "+", 
            RowBox[{"5", 
             SubscriptBox["x", "2"]}], "-", "50"}], ")"}]}], "<=", "0"}]}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["x", "1"], "+", 
             SubscriptBox["x", "2"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}]}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", "*", 
             SubscriptBox["x", "2"]}], "-", 
            SubscriptBox["x", "1"]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"ODE", " ", "from", " ", "Arrowsmith"}], " ", "&"}], " ", 
       "Place", "  ", "Fig", " ", "3.5", 
       RowBox[{"(", "e", ")"}], " ", 
       RowBox[{"p", ".", " ", "79"}]}], " ", "*)"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"77227", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "5947510"}], "+", 
              RowBox[{"100000", " ", 
               SubsuperscriptBox["x", "1", "2"]}], "+", 
              RowBox[{"255958", " ", 
               SubscriptBox["x", "2"]}], "+", 
              RowBox[{
               SubscriptBox["x", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1980490"}], "+", 
                 RowBox[{"540651", " ", 
                  SubscriptBox["x", "2"]}]}], ")"}]}]}], ")"}]}], 
           "250000000000"]}], "<=", "0"}], "  ", "&&", " ", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["x", "2"]}], "<=", 
         SubscriptBox["x", "1"]}], "&&", " ", 
        RowBox[{
         SubscriptBox["x", "1"], "\[GreaterEqual]", "5"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "70"}], "-", 
          RowBox[{"100", " ", 
           SubscriptBox["x", "1"]}], "+", 
          RowBox[{"70", " ", 
           SubsuperscriptBox["x", "1", "2"]}], "+", 
          RowBox[{"100", " ", 
           SubsuperscriptBox["x", "1", "3"]}], "-", 
          RowBox[{"200", " ", 
           SubscriptBox["x", "2"]}], "+", 
          RowBox[{"200", " ", 
           SubsuperscriptBox["x", "1", "2"], " ", 
           SubscriptBox["x", "2"]}]}], ",", 
         RowBox[{
          RowBox[{"146", " ", 
           SubscriptBox["x", "1"]}], "+", 
          RowBox[{"100", " ", 
           SubscriptBox["x", "2"]}], "+", 
          RowBox[{"140", " ", 
           SubscriptBox["x", "1"], " ", 
           SubscriptBox["x", "2"]}], "+", 
          RowBox[{"100", " ", 
           SubsuperscriptBox["x", "1", "2"], " ", 
           SubscriptBox["x", "2"]}], "+", 
          RowBox[{"200", " ", 
           SubscriptBox["x", "1"], " ", 
           SubsuperscriptBox["x", "2", "2"]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"]}], "}"}], ",", "True"}], "}"}], "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"ODE", " ", "from", " ", "Dumortier"}], ",", " ", 
       RowBox[{
        RowBox[{"Llibre", " ", "&"}], " ", "Artes"}], ",", " ", 
       RowBox[{"Exercise", " ", "10.11"}]}], " ", "*)"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}], "+", 
          RowBox[{
           SubscriptBox["x", "3"], "^", "2"}], " ", "-", "2"}], 
         "\[LessEqual]", "0"}], " ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "1"], "\[LessEqual]", "1"}], "  ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "2"], "\[GreaterEqual]", 
         RowBox[{"-", "1"}]}], " ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "3"], "\[LessEqual]", "1"}], " ", "&&", 
        RowBox[{
         SubscriptBox["x", "3"], "\[GreaterEqual]", 
         RowBox[{"-", "1"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            SubsuperscriptBox["x", "1", "3"], ")"}]}], "-", 
          RowBox[{
           SubscriptBox["x", "2"], "^", "2"}]}], ",", 
         RowBox[{"-", " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["x", "2", "3"], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["x", "3"], 
               SubscriptBox["x", "1"]}], ")"}], "^", "2"}]}], ")"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           SubsuperscriptBox["x", "3", "3"], ")"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"Artificially", " ", "constructed", " ", "example"}], " ", 
      "*)"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            SubscriptBox["x", "1"], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["x", "2"]}], ")"}], "^", "2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            SubscriptBox["x", "3"], ")"}], "^", "2"}]}], "<=", " ", 
         RowBox[{"1", "/", "2"}]}], " ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "1"], "\[LessEqual]", " ", 
         RowBox[{"10000", "/", "40005"}]}], "  ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "2"], "\[GreaterEqual]", 
         RowBox[{
          RowBox[{"-", " ", "10000"}], "/", "40007"}]}], " ", "&&", " ", 
        RowBox[{
         SubscriptBox["x", "3"], "\[LessEqual]", " ", 
         RowBox[{"10000", "/", "40011"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["x", "1"]}], "+", 
          RowBox[{"2", "*", 
           RowBox[{
            SubscriptBox["x", "2"], "^", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "^", "2"}], "-", 
          SubscriptBox["x", "2"], "+", 
          RowBox[{
           SubscriptBox["x", "3"], "^", "2"}]}], ",", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SubscriptBox["x", "1"], "^", "2"}]}], "-", 
          SubscriptBox["x", "3"]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}]}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"3", "-", 
       RowBox[{"dimensional", " ", "ODE", " ", "taken", " ", "from", " ", 
        RowBox[{"K", ".", " ", "Forsman"}], " ", 
        RowBox[{"PhD", ".", " ", "thesis"}]}]}], ",", " ", "1991", ",", " ", 
      RowBox[{"page", " ", "101"}], ",", " ", 
      RowBox[{"Example", " ", "6.3"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["x", "3"], "\[GreaterEqual]", " ", 
         RowBox[{"-", "5"}]}], "  ", "||", " ", 
        RowBox[{
         SubscriptBox["x", "3"], "\[LessEqual]", " ", "100"}], " ", "||", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "\[GreaterEqual]", "1"}], " ", "&&", " ", 
          RowBox[{
           SubscriptBox["x", "2"], "\[LessEqual]", "12"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["x", "2"], ",", 
          RowBox[{
           SubscriptBox["x", "1"], "-", 
           RowBox[{"a", "*", 
            SubscriptBox["x", "2"]}], "-", 
           RowBox[{
            SubscriptBox["x", "1"], "*", 
            SubscriptBox["x", "3"]}]}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "b"}], "*", 
            SubscriptBox["x", "3"]}], "+", 
           RowBox[{
            SubscriptBox["x", "1"], "^", "2"}]}]}], " ", "}"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "\[Rule]", " ", "1"}], ",", 
          RowBox[{"b", "\[Rule]", "1"}]}], "}"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["x", "1"], ",", 
         SubscriptBox["x", "2"], ",", 
         SubscriptBox["x", "3"]}], "}"}], ",", "True"}], "}"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Shimizu", "-", 
      RowBox[{"Morioka", " ", "system"}]}], "  ", "*)"}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.639063103699388*^9, 3.639063163775113*^9}, {
   3.639063278915653*^9, 3.639063293452002*^9}, {3.639063332458609*^9, 
   3.6390633375746183`*^9}, {3.6390633695538683`*^9, 3.639063399987831*^9}, {
   3.639064589342628*^9, 3.639064589650206*^9}, {3.6390646476255217`*^9, 
   3.6390646482560453`*^9}, {3.639064905527721*^9, 3.639064945056615*^9}, 
   3.639064991951832*^9, {3.6390672448861313`*^9, 3.639067264191354*^9}, {
   3.6390674062830048`*^9, 3.63906741009448*^9}, {3.639067893566225*^9, 
   3.639067934824462*^9}, {3.639069183180417*^9, 3.6390692203737507`*^9}, {
   3.639069631405818*^9, 3.639069671582931*^9}, 3.639069767207366*^9, {
   3.6390698494250107`*^9, 3.639069850315034*^9}, {3.63906988460923*^9, 
   3.639069884706143*^9}, 3.639070105824128*^9, 3.639070296236061*^9, {
   3.63907074448368*^9, 3.639070805097973*^9}, 3.63907116229251*^9, {
   3.639071246601976*^9, 3.639071250438241*^9}, {3.639073610148934*^9, 
   3.639073657355117*^9}, {3.639073721980929*^9, 3.639073738745553*^9}, {
   3.639073792246913*^9, 3.639073804609275*^9}, {3.6390739334820223`*^9, 
   3.63907406376036*^9}, {3.6390741043874083`*^9, 3.639074375964466*^9}, {
   3.639074841343608*^9, 3.639074891365322*^9}, {3.639074925366707*^9, 
   3.6390751929570293`*^9}, {3.639139327457868*^9, 3.639139327963459*^9}, {
   3.6391393639156427`*^9, 3.6391394133993607`*^9}, {3.639139464314454*^9, 
   3.639139485515092*^9}, {3.6391395315857687`*^9, 3.6391396033464127`*^9}, {
   3.639139776253541*^9, 3.63913979484124*^9}, {3.639139836913431*^9, 
   3.6391399394578743`*^9}, {3.6391399818074093`*^9, 3.639140075510627*^9}, {
   3.63914011218967*^9, 
   3.639140120589322*^9}},ExpressionUUID->"4eee331a-97f7-4d4c-9262-\
2f7e875bebbb"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Timing", "[", 
         RowBox[{"SemiAlgInv`NSSBC", "[", 
          RowBox[{"Apply", "[", 
           RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "]"}], "&"}], 
       ",", " ", "InvariantsNSSBC"}], "]"}], " ", "//", 
     RowBox[{"Timing", "\[IndentingNewLine]", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Timing", "[", 
          RowBox[{"SemiAlgInv`InvS", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "]"}], "&"}], 
        ",", " ", "InvariantsNSSBC"}], "]"}]}]}], " ", "//", "Timing"}], "  ",
    "*)"}]}]], "Input",
 CellChangeTimes->{{3.639063152050076*^9, 3.639063176251031*^9}, {
  3.639067325888495*^9, 3.639067344549945*^9}, {3.639140382955224*^9, 
  3.639140385170104*^9}, {3.639140456168889*^9, 
  3.639140465539999*^9}},ExpressionUUID->"095feaa7-478a-41de-b597-\
c5df4977553d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "InvariantsNSSBC", "]"}]], "Input",
 CellChangeTimes->{{3.639070418991725*^9, 3.6390704198453608`*^9}, {
  3.639140394148904*^9, 
  3.6391403952764874`*^9}},ExpressionUUID->"c75282d1-dfce-4890-b3b2-\
bb483b229cb6"],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.639070420455536*^9, 3.6390735637798653`*^9, 
  3.639074012512561*^9, 3.639074237151907*^9, 3.6390743575307217`*^9, 
  3.6390756794397507`*^9, 3.639140421299019*^9, 
  3.7143853528791847`*^9},ExpressionUUID->"ee45d8b4-ad25-431b-90e6-\
22bafa6c74c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Timing", "[", 
        RowBox[{"SemiAlgInv`NSSBC", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "]"}], "&"}], 
      ",", " ", 
      RowBox[{"InvariantsNSSBC", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "]"}], " ", "//", 
    "Timing"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Timing", "[", 
        RowBox[{"SemiAlgInv`InvS", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "]"}], "&"}], 
      ",", " ", 
      RowBox[{"InvariantsNSSBC", "[", 
       RowBox[{"[", 
        RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "]"}], " ", "//", "Timing", 
    " "}]}]}]], "Input",
 CellChangeTimes->{{3.639073672777278*^9, 3.639073681876287*^9}, {
  3.639073764178708*^9, 3.6390737841102333`*^9}, {3.6390749383642178`*^9, 
  3.639074943573511*^9}, {3.639139434876954*^9, 3.639139440025413*^9}, {
  3.639139633908662*^9, 3.6391396408903723`*^9}, {3.639139823860218*^9, 
  3.639139825723711*^9}, {3.639140403143572*^9, 3.63914040532022*^9}, {
  3.639140467062622*^9, 
  3.639140482311384*^9}},ExpressionUUID->"7cfbd7ce-c73d-4d90-9aca-\
874f4ff9b156"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.744672`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.046521`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.189786`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.421309`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.086976`", ",", "True"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.639140469681581*^9, 3.6391404849154463`*^9}, 
   3.7143853567673883`*^9},ExpressionUUID->"013ae35a-e3bf-45ea-b077-\
baf125e149d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.812875`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.506085`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11.491501`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.512242`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.30298`", ",", "True"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.639140469681581*^9, 3.6391404849154463`*^9}, 
   3.7143853726485443`*^9},ExpressionUUID->"7f38f96a-4a90-4fbb-a647-\
3b23c61b6829"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.639140400394567*^9},ExpressionUUID->"a34400e5-656b-488d-a9e6-\
a356f3d83b00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Timing", "[", 
       RowBox[{"SemiAlgInv`NSSBC", "[", 
        RowBox[{"Apply", "[", 
         RowBox[{"Sequence", ",", " ", "#"}], "]"}], "]"}], "]"}], "&"}], ",",
      " ", 
     RowBox[{"InvariantsDI", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "]"}], " ", "//", 
   "Timing"}]}]], "Input",
 CellChangeTimes->{{3.639140613953293*^9, 
  3.63914061409702*^9}},ExpressionUUID->"07737505-9f35-4cdb-8a01-\
99de1468dfd9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.399258`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.014691`", ",", "False"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.225069`", ",", "False"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01572`", ",", "True"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.143678`", ",", "True"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6391406295539637`*^9, 3.639140750671377*^9, 
  3.71438537450165*^9},ExpressionUUID->"dde51e3c-1607-4e0f-b427-e7777a55ee79"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AtomicRun", "[", 
     RowBox[{"method_", ",", "problem_"}], "]"}], ":=", 
    RowBox[{"Catch", "[", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "tmp", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"tmp", "=", 
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{"TrueQ", "[", 
            RowBox[{"method", "[", 
             RowBox[{"Apply", "[", 
              RowBox[{"Sequence", ",", "problem"}], "]"}], "]"}], "]"}], 
           "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x_Real", "\[Rule]", 
             RowBox[{"NumberForm", "[", 
              RowBox[{"x", ",", 
               RowBox[{"{", 
                RowBox[{"4", ",", "3"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"False", "\[Rule]", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<\[UpTee]\>\"", ",", "Bold", ",", "Black"}], 
              "]"}]}], ",", 
            RowBox[{"True", "\[Rule]", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<True\>\"", ",", "Bold", ",", "Black"}], "]"}]}]}], 
           "}"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ClearSystemCache", "[", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Throw", "[", "tmp", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RunBenchmark", "[", 
     RowBox[{"benchmark_", ",", "TC_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "tab", "}"}], ",", 
      RowBox[{
       RowBox[{"tab", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
            "\"\<\>\"", ",", "\"\<Prob.\>\"", ",", "\"\<Dim\>\"", ",", " ", 
             "\"\<LZZ\>\"", ",", " ", "\"\<DI\>\"", ",", "\"\<NSSBC\>\""}], 
            "}"}], "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{"\"\<Problem\>\"", " ", ",", "i"}], "]"}], ";", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"\"\<\>\"", ",", "i"}], "}"}], ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Length", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"benchmark", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", " ", 
                 RowBox[{"Length", "[", 
                  RowBox[{"Tactics`PostRHSFactors", "[", 
                   RowBox[{"Apply", "[", 
                    RowBox[{"Sequence", ",", " ", 
                    RowBox[{"benchmark", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], 
                "}"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"TimeConstrained", "[", 
                   RowBox[{
                    RowBox[{"AtomicRun", "[", 
                    RowBox[{"InvMethod", ",", 
                    RowBox[{"benchmark", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", "TC"}], 
                   "]"}], "/.", 
                  RowBox[{"{", 
                   RowBox[{"$Aborted", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StringForm", "[", 
                    RowBox[{"\"\<>``s\>\"", ",", "TC"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"\"\<Timeout\>\"", ",", "White", ",", "Bold", ",", 
                    RowBox[{"Background", "\[Rule]", "Gray"}]}], "]"}]}], 
                    "}"}]}], "}"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"InvMethod", ",", 
                   RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    "SemiAlgInv`InvS", ",", "\[IndentingNewLine]", 
                    "SemiAlgInv`DiffInv", ",", "\[IndentingNewLine]", 
                    "SemiAlgInv`NSSBC"}], "\[IndentingNewLine]", "}"}]}], 
                  "}"}]}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "benchmark", "]"}]}], "}"}]}], "]"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"TableForm", "[", "tab", "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Count", " ", "the", " ", "number", " ", "of", " ", "problem", " ", 
    "solved", " ", "in", " ", "less", " ", "than", " ", "or", " ", "equal", 
    " ", "\"\<t\>\"", " ", "s"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"solved", "=", 
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"#1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x_", "/;", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[LessEqual]", "#2"}]}], ",", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<True\>\"", ",", "Bold", ",", "Black"}], "]"}], "|", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<True\>\"", ",", "Bold", ",", "Black"}], "]"}], ",", 
            "_"}], "}"}], "|", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<False\>\"", ",", "Bold", ",", "Red"}], "]"}], ",", 
            "_"}], "}"}]}]}], "}"}]}], "]"}], "&"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "Graphs", " ", 
    SubscriptBox["log", "10"], 
    RowBox[{"(", "t", ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GenGraph", "[", 
   RowBox[{"benchmark_", ",", "TC_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R", ",", "T", ",", "L", ",", "tmp", ",", 
      RowBox[{"delta", "=", "0.01"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"R", "=", "benchmark"}], ";", "\[IndentingNewLine]", 
     RowBox[{"T", "=", 
      RowBox[{"Range", "[", 
       RowBox[{"delta", ",", "TC", ",", "delta"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp", "=", 
      RowBox[{"R", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", 
         RowBox[{"2", ";;"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Reap", "[", 
             RowBox[{"Do", "[", 
              RowBox[{
               RowBox[{"Sow", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"solved", "[", 
                   RowBox[{
                    RowBox[{"tmp", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "#"}], "]"}], "]"}], ",", "t"}], 
                   "]"}], ",", 
                  RowBox[{"Log", "[", 
                   RowBox[{"10", ",", "t"}], "]"}]}], "}"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "T"}], "}"}]}], "]"}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}], "&"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"5", ",", "7"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"L", ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "tmp", "]"}], ",", 
               RowBox[{"-", "0.5"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "tmp", "]"}], ",", 
               RowBox[{"Log", "[", 
                RowBox[{"10", ",", "TC"}], "]"}]}], "}"}]}], "}"}], "}"}]}], 
         "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ListLinePlot", "[", 
      RowBox[{"L", ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<LZZ\>\"", ",", " ", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<OpenType\>\""}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<DI\>\"", ",", " ", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<OpenType\>\""}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<NSSBC\>\"", " ", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<OpenType\>\""}]}], "]"}]}], 
         "\[IndentingNewLine]", "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
          RowBox[{"Directive", "[", 
           RowBox[{"Red", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Directive", "[", 
           RowBox[{"Green", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesOrigin", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", " ", "True"}], ",", " ", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<nb of solved problems \>\"", ",", "\"\<Time (s)\>\""}], 
         "}"}]}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Larger", ",", "Plain", ",", " ", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<OpenType\>\""}]}], "]"}]}], 
       ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2"}], ",", "0.01"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0.1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "10"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"2", ",", "100"}], "}"}]}], "}"}], ",", "None"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5", ",", "10", ",", "20", ",", "30", ",", "40", ",", "50", ",", 
              "60", ",", "70", ",", "80", ",", "90", ",", "100"}], "}"}], ",",
             "None"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"GridLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", 
            RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2"}], "}"}]}], 
         "}"}]}]}], "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6391388770422707`*^9, 3.639138894300767*^9}, {
  3.6391405301216593`*^9, 
  3.639140552693879*^9}},ExpressionUUID->"110d53a7-256e-407a-8805-\
8140eca3a68b"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.639138561607905*^9, 3.63913858896063*^9}, 
   3.639140414266356*^9},ExpressionUUID->"e3812a02-3329-49be-a193-\
414883567e68"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aa", "=", 
  RowBox[{"RunBenchmark", "[", 
   RowBox[{"InvariantsNSSBC", ",", " ", "10"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.639138642525463*^9, 3.639138647285755*^9}, {
  3.639140143193529*^9, 3.639140148109812*^9}, {3.639140560419099*^9, 
  3.6391405835079813`*^9}},ExpressionUUID->"05f0714e-ad4e-4fa1-b86f-\
90a9b74e8206"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Problem", 1],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.71438537468438*^9},ExpressionUUID->"fc6b9370-e4b2-4ce0-b619-\
e38c1d6ed1ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Problem", 2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385375230075*^9},ExpressionUUID->"add3fd4f-87a9-4e44-a689-\
dc4609eec943"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "3"}],
  SequenceForm["Problem", 3],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385385888526*^9},ExpressionUUID->"9c183f1f-5c19-4d37-8f3f-\
e9d3bc9978f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["Problem", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385389465139*^9},ExpressionUUID->"1c4f2aeb-ca48-4b5c-8f58-\
40444c356159"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["Problem", 5],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.7143853909074306`*^9},ExpressionUUID->"f4a01982-99c4-4b3d-8bc9-\
8afd114bb7cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["Problem", 6],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385396112342*^9},ExpressionUUID->"03050a9d-be4b-459d-a234-\
013c29e55482"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "7"}],
  SequenceForm["Problem", 7],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385398331478*^9},ExpressionUUID->"a68bb6af-cd2c-4649-8eb1-\
a802b91932e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm["Problem", 8],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385403755907*^9},ExpressionUUID->"07ba74ff-b31b-491f-afc6-\
11d8a9868a7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["Problem", 9],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385405758955*^9},ExpressionUUID->"a3b7ebd1-bf1d-4b33-80ff-\
3fe36a4a7b2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Problem\"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["Problem", 10],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.639138649091283*^9, 3.6391401495868607`*^9, 3.639140192114442*^9, 
   3.6391404214604387`*^9, {3.6391405614641533`*^9, 3.639140584030673*^9}, 
   3.714385425774979*^9},ExpressionUUID->"591aef0a-a494-4dae-8316-\
a4a282398b6f"]
}, Open  ]],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"\"\>", "\<\"Prob.\"\>", "\<\"Dim\"\>", "\<\"LZZ\"\>", "\<\"DI\"\>", \
"\<\"NSSBC\"\>", "\<\"\"\>"},
    {"\<\"\"\>", "1", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.508\"\>",
          0.507687,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.005\"\>",
          0.004995,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.023\"\>",
          0.022701,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "2", "2", "4", GridBox[{
       {
        InterpretationBox["\<\">\\!\\(\\*RowBox[{\\\"10\\\"}]\\)s\"\>",
         StringForm[">``s", 10],
         Editable->False]},
       {
        StyleBox["\<\"Timeout\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[1],
         FrontFaceColor->GrayLevel[1],
         BackFaceColor->GrayLevel[1],
         GraphicsColor->GrayLevel[1],
         FontWeight->Bold,
         FontColor->GrayLevel[1],
         Background->GrayLevel[0.5]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.007\"\>",
          0.006581,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.219\"\>",
          0.218665,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "3", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"2.713\"\>",
          2.713164,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.003\"\>",
          0.002533,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.438\"\>",
          0.438021,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "4", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"1.291\"\>",
          1.290848,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.002\"\>",
          0.002054,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.091\"\>",
          0.09077,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "5", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"4.712\"\>",
          4.71161,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.002\"\>",
          0.002453,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.241\"\>",
          0.241321,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "6", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"1.919\"\>",
          1.918819,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.003\"\>",
          0.003046,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.172\"\>",
          0.171897,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "7", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"4.419\"\>",
          4.419076,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.004\"\>",
          0.003534,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.376\"\>",
          0.375781,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "8", "2", "4", GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"1.880\"\>",
          1.880325,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.004\"\>",
          0.004374,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.055\"\>",
          0.055019,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"True\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "9", "2", "4", GridBox[{
       {
        InterpretationBox["\<\">\\!\\(\\*RowBox[{\\\"10\\\"}]\\)s\"\>",
         StringForm[">``s", 10],
         Editable->False]},
       {
        StyleBox["\<\"Timeout\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[1],
         FrontFaceColor->GrayLevel[1],
         BackFaceColor->GrayLevel[1],
         GraphicsColor->GrayLevel[1],
         FontWeight->Bold,
         FontColor->GrayLevel[1],
         Background->GrayLevel[0.5]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.002\"\>",
          0.002319,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        InterpretationBox["\<\">\\!\\(\\*RowBox[{\\\"10\\\"}]\\)s\"\>",
         StringForm[">``s", 10],
         Editable->False]},
       {
        StyleBox["\<\"Timeout\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[1],
         FrontFaceColor->GrayLevel[1],
         BackFaceColor->GrayLevel[1],
         GraphicsColor->GrayLevel[1],
         FontWeight->Bold,
         FontColor->GrayLevel[1],
         Background->GrayLevel[0.5]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"\"\>", "10", "2", "4", GridBox[{
       {
        InterpretationBox["\<\">\\!\\(\\*RowBox[{\\\"10\\\"}]\\)s\"\>",
         StringForm[">``s", 10],
         Editable->False]},
       {
        StyleBox["\<\"Timeout\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[1],
         FrontFaceColor->GrayLevel[1],
         BackFaceColor->GrayLevel[1],
         GraphicsColor->GrayLevel[1],
         FontWeight->Bold,
         FontColor->GrayLevel[1],
         Background->GrayLevel[0.5]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        TagBox[
         InterpretationBox["\<\"0.004\"\>",
          0.003605,
          AutoDelete->True],
         NumberForm[#, {4, 3}]& ]},
       {
        StyleBox["\<\"\[UpTee]\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[0],
         FrontFaceColor->GrayLevel[0],
         BackFaceColor->GrayLevel[0],
         GraphicsColor->GrayLevel[0],
         FontWeight->Bold,
         FontColor->GrayLevel[0]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {
        InterpretationBox["\<\">\\!\\(\\*RowBox[{\\\"10\\\"}]\\)s\"\>",
         StringForm[">``s", 10],
         Editable->False]},
       {
        StyleBox["\<\"Timeout\"\>",
         StripOnInput->False,
         LineColor->GrayLevel[1],
         FrontFaceColor->GrayLevel[1],
         BackFaceColor->GrayLevel[1],
         GraphicsColor->GrayLevel[1],
         FontWeight->Bold,
         FontColor->GrayLevel[1],
         Background->GrayLevel[0.5]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"", "Prob.", "Dim", "LZZ", "DI", "NSSBC"}, {"", 1, 2, 4, {
      NumberForm[0.507687, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.004995, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.022701, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 2, 2, 4, {
      StringForm[">``s", 10], 
      Style["Timeout", 
       GrayLevel[1], Bold, Background -> GrayLevel[0.5]]}, {
      NumberForm[0.006581, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.218665, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 3, 2, 4, {
      NumberForm[2.713164, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.002533, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.438021, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 4, 2, 4, {
      NumberForm[1.290848, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.002054, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.09077, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 5, 2, 4, {
      NumberForm[4.71161, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.002453, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.241321, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 6, 2, 4, {
      NumberForm[1.918819, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.003046, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.171897, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 7, 2, 4, {
      NumberForm[4.419076, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.003534, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.375781, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 8, 2, 4, {
      NumberForm[1.880325, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.004374, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      NumberForm[0.055019, {4, 3}], 
      Style["True", Bold, 
       GrayLevel[0]]}}, {"", 9, 2, 4, {
      StringForm[">``s", 10], 
      Style["Timeout", 
       GrayLevel[1], Bold, Background -> GrayLevel[0.5]]}, {
      NumberForm[0.002319, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      StringForm[">``s", 10], 
      Style["Timeout", 
       GrayLevel[1], Bold, Background -> GrayLevel[0.5]]}}, {"", 10, 2, 4, {
      StringForm[">``s", 10], 
      Style["Timeout", 
       GrayLevel[1], Bold, Background -> GrayLevel[0.5]]}, {
      NumberForm[0.003605, {4, 3}], 
      Style["\[UpTee]", Bold, 
       GrayLevel[0]]}, {
      StringForm[">``s", 10], 
      Style["Timeout", 
       GrayLevel[1], Bold, Background -> GrayLevel[0.5]]}}}]]], "Output",
 CellChangeTimes->{3.639138738097884*^9, 3.639140153175061*^9, 
  3.639140195377286*^9, 3.639140425658078*^9, 3.6391405797076406`*^9, 
  3.639140623450314*^9, 
  3.714385445814571*^9},ExpressionUUID->"23abeff0-1fee-49dc-af74-\
dd63bb28e6b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenGraph", "[", 
  RowBox[{"aa", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{
  3.639138864743335*^9},ExpressionUUID->"8e738531-1d8e-4cb1-9728-\
b4aae2df6eef"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1], 
         Thickness[Large], 
         Dashing[{Small, Small}]], 
        LineBox[CompressedData["
1:eJxd2nc8Vv//P3CrMlOSUWZKhAbJyiopVCIjUSgjUqLMIiQJWRWikEjZyR4p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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], 
         RGBColor[1, 0, 0], 
         Thickness[Large]], 
        LineBox[CompressedData["
1:eJxd2nc4VnH/B3CiMhuSUWZKhAbJyiopVCIjUSgjI6LMIkoSsipEIZGykz1S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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.005555555555555556], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 1, 0], 
         Thickness[Large]], 
        LineBox[CompressedData["
1:eJxV2nc8V+//P3Ar2UoyykyJ0CBZWSW9UYmMRKGMjIgyi5AkZFWIQlKKjGSP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         "]]}}}, {}, {}, {{}, {}}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, AxesOrigin -> {0., -1.}, 
     PlotRange -> {{0., 8.}, {-1.9999999999999996`, 1.}}, PlotRangeClipping -> 
     True, ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0., -1.}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox["\"Time (s)\"", TraditionalForm], None}, {
        FormBox["\"nb of solved problems \"", TraditionalForm], None}}, 
     FrameTicks -> {{{{-2, 
          FormBox["0.01`", TraditionalForm]}, {-1, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {1, 
          FormBox["10", TraditionalForm]}, {2, 
          FormBox["100", TraditionalForm]}}, None}, {{{5, 
          FormBox["5", TraditionalForm]}, {10, 
          FormBox["10", TraditionalForm]}, {20, 
          FormBox["20", TraditionalForm]}, {30, 
          FormBox["30", TraditionalForm]}, {40, 
          FormBox["40", TraditionalForm]}, {50, 
          FormBox["50", TraditionalForm]}, {60, 
          FormBox["60", TraditionalForm]}, {70, 
          FormBox["70", TraditionalForm]}, {80, 
          FormBox["80", TraditionalForm]}, {90, 
          FormBox["90", TraditionalForm]}, {100, 
          FormBox["100", TraditionalForm]}}, None}}, 
     GridLines -> {None, {-2, -1, 0, 1, 2}}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], LabelStyle -> 
     Directive[Larger, Plain, FontFamily -> "OpenType"], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0., 8.}, {-1.9999999999999996`, 1.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       StyleBox["\"LZZ\"", FontFamily -> "OpenType", StripOnInput -> False], 
       StyleBox["\"DI\"", FontFamily -> "OpenType", StripOnInput -> False], 
       StyleBox[
       "\"NSSBC\"", FontFamily -> "OpenType", StripOnInput -> False]}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.05], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          Directive[Larger, Plain, FontFamily -> "OpenType"], FontFamily -> 
          "Arial"}, Background -> Automatic, StripOnInput -> False], 
        TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.005555555555555556`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
               RowBox[{"Larger", ",", "Plain", ",", 
                 RowBox[{"FontFamily", "\[Rule]", "\"OpenType\""}]}], "]"}]}],
            ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.639138815212891*^9, 3.6391388661602077`*^9, 
  3.6391389043233137`*^9, 
  3.7143854465444813`*^9},ExpressionUUID->"a059e667-3945-4e6c-bba0-\
a3c02ef722f8"]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{
  3.639139002319829*^9},ExpressionUUID->"f77520a0-cb3c-444b-8e02-\
cedcf17e5b4b"]
},
WindowSize->{1366, 735},
WindowMargins->{{51, Automatic}, {205, Automatic}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1867, 35, 562, "Text", "ExpressionUUID" -> \
"79ddb1b2-2733-49c0-8b54-0af0d15b84d3"],
Cell[2428, 57, 321, 8, 32, "Input", "ExpressionUUID" -> \
"bedb01e8-10f7-4a78-a0d8-0929b1c70bc5"],
Cell[2752, 67, 16145, 471, 270, "Input", "ExpressionUUID" -> \
"5bf8d57e-38a3-487c-8b2a-4f268542fc40"],
Cell[18900, 540, 1162, 30, 96, "Input", "ExpressionUUID" -> \
"e0b79eca-2b4b-4c54-b3d2-9ff32e43b880"],
Cell[20065, 572, 25422, 703, 732, "Input", "ExpressionUUID" -> \
"4eee331a-97f7-4d4c-9262-2f7e875bebbb"],
Cell[45490, 1277, 1042, 27, 54, "Input", "ExpressionUUID" -> \
"095feaa7-478a-41de-b597-c5df4977553d"],
Cell[CellGroupData[{
Cell[46557, 1308, 252, 5, 32, "Input", "ExpressionUUID" -> \
"c75282d1-dfce-4890-b3b2-bb483b229cb6"],
Cell[46812, 1315, 299, 5, 32, "Output", "ExpressionUUID" -> \
"ee45d8b4-ad25-431b-90e6-22bafa6c74c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47148, 1325, 1367, 36, 54, "Input", "ExpressionUUID" -> \
"7cfbd7ce-c73d-4d90-9aca-874f4ff9b156"],
Cell[48518, 1363, 559, 15, 32, "Output", "ExpressionUUID" -> \
"013ae35a-e3bf-45ea-b077-baf125e149d4"],
Cell[49080, 1380, 560, 15, 32, "Output", "ExpressionUUID" -> \
"7f38f96a-4a90-4fbb-a647-3b23c61b6829"]
}, Open  ]],
Cell[49655, 1398, 128, 3, 32, "Input", "ExpressionUUID" -> \
"a34400e5-656b-488d-a9e6-a356f3d83b00"],
Cell[CellGroupData[{
Cell[49808, 1405, 558, 17, 32, "Input", "ExpressionUUID" -> \
"07737505-9f35-4cdb-8a01-99de1468dfd9"],
Cell[50369, 1424, 552, 14, 32, "Output", "ExpressionUUID" -> \
"dde51e3c-1607-4e0f-b427-e7777a55ee79"]
}, Open  ]],
Cell[50936, 1441, 11571, 292, 726, "Input", "ExpressionUUID" -> \
"110d53a7-256e-407a-8805-8140eca3a68b"],
Cell[62510, 1735, 174, 3, 32, "Input", "ExpressionUUID" -> \
"e3812a02-3329-49be-a193-414883567e68"],
Cell[CellGroupData[{
Cell[62709, 1742, 356, 7, 32, "Input", "ExpressionUUID" -> \
"05f0714e-ad4e-4fa1-b86f-90a9b74e8206"],
Cell[CellGroupData[{
Cell[63090, 1753, 399, 9, 24, "Print", "ExpressionUUID" -> \
"fc6b9370-e4b2-4ce0-b619-e38c1d6ed1ce"],
Cell[63492, 1764, 400, 9, 24, "Print", "ExpressionUUID" -> \
"add3fd4f-87a9-4e44-a689-dc4609eec943"],
Cell[63895, 1775, 400, 9, 24, "Print", "ExpressionUUID" -> \
"9c183f1f-5c19-4d37-8f3f-e9d3bc9978f9"],
Cell[64298, 1786, 400, 9, 24, "Print", "ExpressionUUID" -> \
"1c4f2aeb-ca48-4b5c-8f58-40444c356159"],
Cell[64701, 1797, 402, 9, 24, "Print", "ExpressionUUID" -> \
"f4a01982-99c4-4b3d-8bc9-8afd114bb7cf"],
Cell[65106, 1808, 400, 9, 24, "Print", "ExpressionUUID" -> \
"03050a9d-be4b-459d-a234-013c29e55482"],
Cell[65509, 1819, 400, 9, 24, "Print", "ExpressionUUID" -> \
"a68bb6af-cd2c-4649-8eb1-a802b91932e9"],
Cell[65912, 1830, 400, 9, 24, "Print", "ExpressionUUID" -> \
"07ba74ff-b31b-491f-afc6-11d8a9868a7c"],
Cell[66315, 1841, 400, 9, 24, "Print", "ExpressionUUID" -> \
"a3b7ebd1-bf1d-4b33-80ff-3fe36a4a7b2f"],
Cell[66718, 1852, 402, 9, 24, "Print", "ExpressionUUID" -> \
"591aef0a-a494-4dae-8316-a4a282398b6f"]
}, Open  ]],
Cell[67135, 1864, 30566, 895, 354, "Output", "ExpressionUUID" -> \
"23abeff0-1fee-49dc-af74-dd63bb28e6b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97738, 2764, 188, 5, 32, "Input", "ExpressionUUID" -> \
"8e738531-1d8e-4cb1-9728-b4aae2df6eef"],
Cell[97929, 2771, 45940, 835, 252, "Output", "ExpressionUUID" -> \
"a059e667-3945-4e6c-bba0-a3c02ef722f8"]
}, Open  ]],
Cell[143884, 3609, 129, 3, 32, "Input", "ExpressionUUID" -> \
"f77520a0-cb3c-444b-8e02-cedcf17e5b4b"]
}
]
*)

